==> guikachu-0.6.tar.gz: guikachu-0.6/src/form-editor/graffiti.h <==
//$Id: graffiti.h,v 1.2 2001/04/22 13:03:11 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_GRAFITI_H
#define GUIKACHU_FORM_EDITOR_GRAFITI_H

#include <string>
#include <iostream>
#include "widget.h"
#include "resource.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Graffiti;
    }
}

#include "graffiti-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Graffiti: public Widget
	{
	    GUI::FormEditor::GraffitiProperties *editor;
	    
	public:
	    Graffiti (Resources::Form *owner,
		      const string& id);
	    virtual ~Graffiti ();
	    
	    virtual Type get_type () const { return WIDGET_GRAFFITI; };
	    
	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget *get_editor ();
	    
	private:
	    // Persistance
	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
	    virtual void save (xmlNodePtr node) const;
	    virtual void save_rcp (ostream &ostr) const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_GRAFFITI_H */

==> guikachu-0.10.tar.gz: guikachu-0.10/src/form-editor/graffiti.h <==
//$Id: graffiti.h,v 1.5 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_GRAFITI_H
#define GUIKACHU_FORM_EDITOR_GRAFITI_H

#include <string>
#include <iostream>
#include "widget.h"
#include "resource.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Graffiti;
    }
}

#include "graffiti-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class Graffiti: public Widget
	{
	    GUI::FormEditor::GraffitiProperties *editor;
	    
	public:
	    Graffiti (Resources::Form *owner,
		      const string& id);
	    virtual ~Graffiti ();
	    
	    virtual Type get_type () const { return WIDGET_GRAFFITI; };
	    
	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget                 *create_editor ();
	    
	private:
	    // Persistance
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (ostream &ostr) const;
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_GRAFFITI_H */
